@@ -5,7 +5,7 @@ from csv import DictReader
 from logging import getLogger
 from tabulate import tabulate
 from time import sleep
-from typing import List
+from typing import Any, Dict, List
 
 from python_anvil import utils
 
@@ -125,18 +125,19 @@ def weld(ctx, eid, list_all):
 @click.option(
     "-a", "--all", "list_all", help="List all casts, even non-templates", is_flag=True
 )
+@click.option("--version_number", help="Get the specified version of this cast")
 @click.argument("eid", default="")
 @click.pass_context
-def cast(ctx, eid, list_all, list_templates):
+def cast(ctx, eid, version_number, list_all, list_templates):
     """Fetch Cast data given a Cast eid."""
-    anvil = ctx.obj["anvil"]
+    anvil = ctx.obj["anvil"]  # type: Anvil
     debug = ctx.obj["debug"]
 
     if not eid and not (list_templates or list_all):
         raise AssertionError("Cast eid or --list/--all option required")
 
     if list_all or list_templates:
-        res = anvil.get_casts(debug=debug, show_all=list_all)
+        res = anvil.get_casts(show_all=list_all, debug=debug)
 
         if contains_headers(res):
             res, headers = process_response(res)
@@ -149,9 +150,9 @@ def cast(ctx, eid, list_all, list_templates):
 
     if eid:
         click.echo(f"Getting cast with eid '{eid}' \n")
-        res = anvil.get_cast(eid, debug=debug)
+        _res = anvil.get_cast(eid, version_number=version_number, debug=debug)
 
-        if contains_headers(res):
+        if contains_headers(_res):
             res, headers = process_response(res)
             if debug:
                 click.echo(headers)
@@ -159,12 +160,12 @@ def cast(ctx, eid, list_all, list_templates):
         def get_field_info(cc):
             return tabulate(cc.get("fields", []))
 
-        if not res:
+        if not _res:
             click.echo(f"Cast with eid: {eid} not found")
             return
 
-        table_data = [[res["eid"], res["title"], get_field_info(res["fieldInfo"])]]
-        click.echo(tabulate(table_data, tablefmt="pretty", headers=res.keys()))
+        table_data = [[_res["eid"], _res["title"], get_field_info(_res["fieldInfo"])]]
+        click.echo(tabulate(table_data, tablefmt="pretty", headers=list(_res.keys())))
 
 
 @cli.command("fill-pdf")
